KeysVerbBuilder class

KeysVerbBuilder is used to build commands for key (encryption keys) specific put, get and delete operations.

Implemented types

Constructors

KeysVerbBuilder(String operation)

Properties

appName ↔ String?
name of the app which requested this key operation
getter/setter pair
deviceName ↔ String?
name of the device which requested this key operation
getter/setter pair
encryptionKeyName ↔ String?
if the value is encrypted, then encryptionKeyName specifies keyName which encrypted the value
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
keyName ↔ String?
Unique name to identify this key
getter/setter pair
keyType ↔ String?
Encryption key type e.g rsa2048,aes256, ecdsa
getter/setter pair
namespace ↔ String?
namespace of the key e.g __global, __private
getter/setter pair
operation → String
specifies the keys verb operation (get|put|delete)
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value ↔ String?
value of the key. Can be plain text for public keys and encrypted for other keys.
getter/setter pair
visibility ↔ String?
visibility - public. Used for public encryption key from asymmetric keypair visibility - private. Used for private encryption key from asymmetric keypair visibility - self. Used for self encryption key.
getter/setter pair

Methods

buildCommand() → String
Build the @ command to be sent to remote secondary for execution.
override
checkParams() → bool
Checks whether all params required by the verb builder are set. Returns false if required params are not set.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited