NotifyFetchVerbBuilder class

NotifyFetchVerbBuilder generated the command to fetches the notification with the given notification-id

e.g. To fetch the notification with the notification-id - '21d617cd-fb8a-43e4-98df-7e1536818d59'

var notifyFetchVerbBuilder = NotifyFetchVerbBuilder()
                                      ..notificationId = '21d617cd-fb8a-43e4-98df-7e1536818d59';

Throws InvalidSyntaxException if notification id is not set or initialized to empty string
Implemented types

Constructors

NotifyFetchVerbBuilder()

Properties

hashCode → int
The hash code for this object.
no setterinherited
notificationId ↔ String
Notification Id to fetch the notification
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

buildCommand() → String
Build the @ command to be sent to remote secondary for execution.
override
checkParams() → bool
Checks whether all params required by the verb builder are set. Returns false if required params are not set.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited