NotifyListVerbBuilder class

Implemented types

Constructors

NotifyListVerbBuilder()

Properties

fromDate ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
regex ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
toDate ↔ String?
getter/setter pair

Methods

buildCommand() → String
Build the @ command to be sent to remote secondary for execution.
override
checkParams() → bool
Checks whether all params required by the verb builder are set. Returns false if required params are not set.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited