NotifyVerbBuilder class

Implemented types

Constructors

NotifyVerbBuilder()

Properties

atKey ↔ AtKey
Represents the AtKey instance to populate the verb builder data
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String
id for each notification.
getter/setter pair
latestN ↔ int?
Latest N notifications to notify. Defaults to 1
getter/setter pair
messageType ↔ MessageTypeEnum?
type of notification
getter/setter pair
notifier ↔ String
The notifier of the notification. Defaults to system.
getter/setter pair
operation ↔ OperationEnum?
getter/setter pair
priority ↔ PriorityEnum?
priority of the notification
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
strategy ↔ StrategyEnum?
strategy in processing the notification
getter/setter pair
ttln ↔ int?
time in milliseconds after which a notification expires.
getter/setter pair
useAtKeyToString ↔ bool
getter/setter pair
value ↔ dynamic
Value of the key typically in string format. Images, files, etc., must be converted to unicode string before storing.
getter/setter pair

Methods

buildCommand() → String
Build the @ command to be sent to remote secondary for execution.
override
checkParams() → bool
Checks whether all params required by the verb builder are set. Returns false if required params are not set.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
validateKey() → void
Validates the AtKey
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited