ScanVerbBuilder class

Scan verb builder generates a command to scan keys of current atSign(with ot without auth). If a regex is set, keys matching the regex are returned. If a sharedBy is set, then a scan command is send to the secondary server of the sharedBy. If a sharedWith is set, gets the keys shared to sharedWith atSign from the current atSign.

// Scans keys for the self in an unauthenticated way
 var builder = ScanVerbBuilder();

 // Scans keys for the self in an authenticated way
 var builder = ScanVerbBuilder()..auth=true;

 // Scans keys shared by @alice to self in an authenticated way
 var builder = ScanVerbBuilder()..auth=true..forAtSign='alice';

 // Scans keys shared with @alice by self in an authenticated way
 var builder = ScanVerbBuilder()..auth=true..regex='@alice';
Implemented types

Constructors

ScanVerbBuilder()

Properties

auth ↔ bool
If set to true, then all keys(public, private, protected) are returned. If set to false, only the public keys of current atSign are returned.
getter/setter pair
commitLog ↔ bool
If set to true, the server is asked to scan the commit log rather than the keystore. Emitted on the wire as the :cl flag.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
regex ↔ String?
Regular expression to filter keys.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sharedBy ↔ String?
atSign of another secondary server on which scan is run. If sharedBy is set then auth has to be true.
getter/setter pair
sharedWith ↔ String?
atSign to whom the current atClient user has shared the keys. If sharedWith is set then auth has to be true.
getter/setter pair
showHiddenKeys ↔ bool
If set to true, the hidden keys will displayed. Defaulted to false.
getter/setter pair

Methods

buildCommand() → String
Build the @ command to be sent to remote secondary for execution.
override
checkParams() → bool
Checks whether all params required by the verb builder are set. Returns false if required params are not set.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited