commitLog property

bool commitLog
getter/setter pair

If set to true, the server is asked to scan the commit log rather than the keystore. Emitted on the wire as the :cl flag.

Implementation

bool commitLog = false;