noCommit property
When true, the server is asked not to write a commit-log entry for this
update. Emitted on the wire as the :nc flag, valid for both the
metadata-fragment and the update:json:... forms.
Implementation
bool noCommit = false;
When true, the server is asked not to write a commit-log entry for this
update. Emitted on the wire as the :nc flag, valid for both the
metadata-fragment and the update:json:... forms.
bool noCommit = false;