VerbBuilder class abstract

VerbBuilder is used to build @protocol command that can be executed by a secondary server.

Implementers

Constructors

VerbBuilder()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

buildCommand() → String
Build the @ command to be sent to remote secondary for execution.
checkParams() → bool
Checks whether all params required by the verb builder are set. Returns false if required params are not set.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited