InvalidAtKeyException class

Exception thrown when a key is invalid

Inheritance

Constructors

InvalidAtKeyException(String message)

Properties

exceptionScenario ↔ ExceptionScenario?
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
intent ↔ Intent?
getter/setter pairinherited
message ↔ String
Represents error message that details the cause of the exception
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

fromException(AtException atException) → AtException
inherited
getTraceMessage() → String
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
stack(AtChainedException atChainedException) → void
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited