RegexUtil class

Constructors

RegexUtil()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

isPartialMatch(String regex, String input) bool
Checks if the the input is a partial match to the regex
keyType(String key, bool enforceNamespace) KeyType
Returns a first matching key type after matching the key against regexes for each of the key type
matchAll(String regex, String input) bool
Matches a regex against the input Returns a true if the regex is matched to the ENTIRE string, false otherwise
matchesByGroup(String regex, String input) Map<String, String>
Returns a Map containing named groups and the matched values in the input Returns an empty Map if no matches are found